Clazz.declarePackage("JU");
(function(){
var c$ = Clazz.decorateAsClass(function(){
this.x = 0;
this.y = 0;
this.z = 0;
Clazz.instantialize(this, arguments);}, JU, "T3i", null, java.io.Serializable);
/*LV!1824 unnec constructor*/Clazz.defineMethod(c$, "set", 
function(x, y, z){
this.x = x;
this.y = y;
this.z = z;
}, "~N,~N,~N");
Clazz.defineMethod(c$, "setT", 
function(t1){
this.x = t1.x;
this.y = t1.y;
this.z = t1.z;
}, "JU.T3i");
Clazz.defineMethod(c$, "add", 
function(t){
this.x += t.x;
this.y += t.y;
this.z += t.z;
}, "JU.T3i");
Clazz.defineMethod(c$, "scaleAdd", 
function(s, t1, t2){
this.x = s * t1.x + t2.x;
this.y = s * t1.y + t2.y;
this.z = s * t1.z + t2.z;
}, "~N,JU.T3i,JU.T3i");
Clazz.overrideMethod(c$, "hashCode", 
function(){
return this.x ^ this.y ^ this.z;
});
Clazz.overrideMethod(c$, "equals", 
function(o){
if (!(Clazz.instanceOf(o,"JU.T3i"))) return false;
var t = o;
return (this.x == t.x && this.y == t.y && this.z == t.z);
}, "~O");
Clazz.defineMethod(c$, "asString", 
function(){
return "(" + this.x + ", " + this.y + ", " + this.z + ")";
});
Clazz.overrideMethod(c$, "toString", 
function(){
return this.asString();
});
})();
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
